@@ -214,23 +214,29 @@ class CardReversalTransactionDTO(BaseTransactionDTO):
 
 class WireTransactionDTO(BaseTransactionDTO):
     def __init__(self, id: str, created_at: datetime, direction: str, amount: int, balance: int,
-                 summary: str, counterparty: Counterparty, description: str, sender_reference: str,
-                 reference_for_beneficiary: str, tags: Optional[Dict[str, str]],
+                 summary: str, counterparty: Counterparty, description: str, 
+                 originator_to_beneficiary_information: str, sender_reference: str,
+                 reference_for_beneficiary: str, beneficiary_information: str,
+                 beneficiary_advice_information: str, tags: Optional[Dict[str, str]],
                  relationships: Optional[Dict[str, Relationship]]):
         BaseTransactionDTO.__init__(self, id, created_at, direction, amount, balance, summary, tags, relationships)
         self.type = 'wireTransaction'
         self.attributes["description"] = description
         self.attributes["counterparty"] = counterparty
+        self.attributes["originatorToBeneficiaryInformation"] = originator_to_beneficiary_information
         self.attributes["senderReference"] = sender_reference
         self.attributes["referenceForBeneficiary"] = reference_for_beneficiary
+        self.attributes["beneficiaryInformation"] = beneficiary_information
+        self.attributes["beneficiaryAdviceInformation"] = beneficiary_advice_information
 
     @staticmethod
     def from_json_api(_id, _type, attributes, relationships):
         return WireTransactionDTO(_id, date_utils.to_datetime(attributes["createdAt"]), attributes["direction"],
-                                  attributes["amount"], attributes["balance"], attributes["summary"],
-                                  Counterparty.from_json_api(attributes["counterparty"]), attributes["description"],
-                                  attributes["senderReference"], attributes["referenceForBeneficiary"],
-                                  attributes.get("tags"), relationships)
+                                attributes["amount"], attributes["balance"], attributes["summary"],
+                                Counterparty.from_json_api(attributes["counterparty"]), attributes["description"],
+                                attributes.get("originatorToBeneficiaryInformation"), attributes.get("senderReference"), 
+                                attributes.get("referenceForBeneficiary"), attributes.get("beneficiaryInformation"),
+                                attributes.get("beneficiaryAdviceInformation"), attributes.get("tags"), relationships)
 
 
 class ReleaseTransactionDTO(BaseTransactionDTO):
